==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_texture_8h.js <==
var _ogre_texture_8h =
[
    [ "TextureUsage", "_ogre_texture_8h.html#gaf140ec886884a864abc74a7556f8bf67", [
      [ "TU_STATIC", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a375858a86cadfb2a4d20fe837fdb85b3", null ],
      [ "TU_DYNAMIC", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67ad18031f12c4bd22f73b09a4536e99df5", null ],
      [ "TU_WRITE_ONLY", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67af7b0d53154ffc7c389404dc51c792655", null ],
      [ "TU_STATIC_WRITE_ONLY", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a2b9d0399c32f2098957ebc089c337e55", null ],
      [ "TU_DYNAMIC_WRITE_ONLY", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67ac26eda030d21e0491461edea89394493", null ],
      [ "TU_DYNAMIC_WRITE_ONLY_DISCARDABLE", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a79920182637c94fabcf834950096483f", null ],
      [ "TU_AUTOMIPMAP", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a7c14cc95a59af42a63eb33fc9de05d27", null ],
      [ "TU_RENDERTARGET", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67ae1661d9846a9b4e83c2e4cd99fc6ad9d", null ],
      [ "TU_NOT_SRV", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67aeaa879e353bc503f741a0a0671b35c15", null ],
      [ "TU_UAV", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a85ca4e5cb922c3a2381ed5eed01c0cf1", null ],
      [ "TU_UAV_NOT_SRV", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a705be8b4d48b62f98e1cd5d70c2a16a8", null ],
      [ "TU_DEFAULT", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67acaa45fe77d1becf4c5bd353bc2aa764b", null ],
      [ "TU_NOTSHADERRESOURCE", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a186a9408e017e08e63c56db55da7f09f", null ]
    ] ],
    [ "TextureAccess", "_ogre_texture_8h.html#ga12b16f4465fec1b8fff40c719e2aa458", [
      [ "TA_READ", "_ogre_texture_8h.html#gga12b16f4465fec1b8fff40c719e2aa458a183a8dcf97daf2dcd3c7984c8c09040e", null ],
      [ "TA_WRITE", "_ogre_texture_8h.html#gga12b16f4465fec1b8fff40c719e2aa458a8d8ea745f3af07796f15e9608d3e7a2f", null ],
      [ "TA_READ_WRITE", "_ogre_texture_8h.html#gga12b16f4465fec1b8fff40c719e2aa458a36eb7ddb2aa3dfcc79147c4f4d803ae6", null ]
    ] ],
    [ "TextureType", "_ogre_texture_8h.html#gaac3431531c3258e3c1c86ef8a4c06228", [
      [ "TEX_TYPE_1D", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228a18bf88d3a14ba28d6602689e398416bd", null ],
      [ "TEX_TYPE_2D", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228af1f732018f5a2a7d35233e2ceeb4ee0e", null ],
      [ "TEX_TYPE_3D", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228aa80e2545e817591a0b4547f987987d43", null ],
      [ "TEX_TYPE_CUBE_MAP", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228ae295fe0fa26623b66cc023f462962344", null ],
      [ "TEX_TYPE_2D_ARRAY", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228a11589b2d4fbe6213dcdaf4e78894a3a7", null ],
      [ "TEX_TYPE_EXTERNAL_OES", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228a1a31bbe700e223257fb2d18afcb14d73", null ]
    ] ],
    [ "TextureMipmap", "_ogre_texture_8h.html#ga528ce4f4c67c9b043e1f0b8bb3cdf255", [
      [ "MIP_UNLIMITED", "_ogre_texture_8h.html#gga528ce4f4c67c9b043e1f0b8bb3cdf255a5a6b498127bf3fa219dadfdaaa50b9dd", null ],
      [ "MIP_DEFAULT", "_ogre_texture_8h.html#gga528ce4f4c67c9b043e1f0b8bb3cdf255a56eea45719de5246f4ea9b8e8b54921d", null ]
    ] ]
];

==> ogre-14.3.2-2-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_texture_8h.js <==
var _ogre_texture_8h =
[
    [ "TextureUsage", "_ogre_texture_8h.html#gaf140ec886884a864abc74a7556f8bf67", [
      [ "TU_STATIC", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a375858a86cadfb2a4d20fe837fdb85b3", null ],
      [ "TU_DYNAMIC", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67ad18031f12c4bd22f73b09a4536e99df5", null ],
      [ "TU_WRITE_ONLY", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67af7b0d53154ffc7c389404dc51c792655", null ],
      [ "TU_STATIC_WRITE_ONLY", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a2b9d0399c32f2098957ebc089c337e55", null ],
      [ "TU_DYNAMIC_WRITE_ONLY", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67ac26eda030d21e0491461edea89394493", null ],
      [ "TU_DYNAMIC_WRITE_ONLY_DISCARDABLE", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a79920182637c94fabcf834950096483f", null ],
      [ "TU_AUTOMIPMAP", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a7c14cc95a59af42a63eb33fc9de05d27", null ],
      [ "TU_RENDERTARGET", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67ae1661d9846a9b4e83c2e4cd99fc6ad9d", null ],
      [ "TU_NOT_SAMPLED", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a01b70f2cf9ba057c62aa554af7f5f2a8", null ],
      [ "TU_UNORDERED_ACCESS", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67aaaa1e44020b4fcc25600b423f45cd227", null ],
      [ "TU_DEFAULT", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67acaa45fe77d1becf4c5bd353bc2aa764b", null ],
      [ "TU_UAV_NOT_SRV", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a705be8b4d48b62f98e1cd5d70c2a16a8", null ],
      [ "TU_NOT_SRV", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67aeaa879e353bc503f741a0a0671b35c15", null ],
      [ "TU_NOTSHADERRESOURCE", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a186a9408e017e08e63c56db55da7f09f", null ],
      [ "TU_UAV", "_ogre_texture_8h.html#ggaf140ec886884a864abc74a7556f8bf67a85ca4e5cb922c3a2381ed5eed01c0cf1", null ]
    ] ],
    [ "TextureAccess", "_ogre_texture_8h.html#ga12b16f4465fec1b8fff40c719e2aa458", [
      [ "TA_READ", "_ogre_texture_8h.html#gga12b16f4465fec1b8fff40c719e2aa458a183a8dcf97daf2dcd3c7984c8c09040e", null ],
      [ "TA_WRITE", "_ogre_texture_8h.html#gga12b16f4465fec1b8fff40c719e2aa458a8d8ea745f3af07796f15e9608d3e7a2f", null ],
      [ "TA_READ_WRITE", "_ogre_texture_8h.html#gga12b16f4465fec1b8fff40c719e2aa458a36eb7ddb2aa3dfcc79147c4f4d803ae6", null ]
    ] ],
    [ "TextureType", "_ogre_texture_8h.html#gaac3431531c3258e3c1c86ef8a4c06228", [
      [ "TEX_TYPE_1D", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228a18bf88d3a14ba28d6602689e398416bd", null ],
      [ "TEX_TYPE_2D", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228af1f732018f5a2a7d35233e2ceeb4ee0e", null ],
      [ "TEX_TYPE_3D", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228aa80e2545e817591a0b4547f987987d43", null ],
      [ "TEX_TYPE_CUBE_MAP", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228ae295fe0fa26623b66cc023f462962344", null ],
      [ "TEX_TYPE_2D_ARRAY", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228a11589b2d4fbe6213dcdaf4e78894a3a7", null ],
      [ "TEX_TYPE_EXTERNAL_OES", "_ogre_texture_8h.html#ggaac3431531c3258e3c1c86ef8a4c06228a1a31bbe700e223257fb2d18afcb14d73", null ]
    ] ],
    [ "TextureMipmap", "_ogre_texture_8h.html#ga528ce4f4c67c9b043e1f0b8bb3cdf255", [
      [ "MIP_UNLIMITED", "_ogre_texture_8h.html#gga528ce4f4c67c9b043e1f0b8bb3cdf255a5a6b498127bf3fa219dadfdaaa50b9dd", null ],
      [ "MIP_DEFAULT", "_ogre_texture_8h.html#gga528ce4f4c67c9b043e1f0b8bb3cdf255a56eea45719de5246f4ea9b8e8b54921d", null ]
    ] ]
];
